@@ -20,7 +20,7 @@ class CommandPSD4(Command):
         if self.checkValueInInterval(value, 3000, 24000):
             cmd += str(value)
         else:
-            print("Wrong parameter value PSD4 for absolute position command!")
+            print("Invalid value " + str(value) + " for PSD4 absolute position command!")
             cmd = 'cmdError'
         return cmd
 
@@ -30,7 +30,7 @@ class CommandPSD4(Command):
         if self.checkValueInInterval(value, 3000, 24000):
             cmd += str(value)
         else:
-            print("Wrong parameter value PSD4 for absolute position with ready status command!")
+            print("Invalid value " + str(value) + " for PSD4 absolute position with ready status command!")
             cmd = 'cmdError'
         return cmd
 
@@ -40,7 +40,7 @@ class CommandPSD4(Command):
         if self.checkValueInInterval(value, 3000, 24000):
             cmd += str(value)
         else:
-            print("Wrong parameter value for relative pickup command!")
+            print("Invalid value " + str(value) + " for PSD4 relative pickup command!")
             cmd = 'cmdError'
         return cmd
 
@@ -50,7 +50,7 @@ class CommandPSD4(Command):
         if self.checkValueInInterval(value, 3000, 24000):
             cmd += str(value)
         else:
-            print("Wrong parameter value for relative pickup with ready status command!")
+            print("Invalid value " + str(value) + " for PSD4 relative pickup with ready status command!")
             cmd = 'cmdError'
         return cmd
 
@@ -60,7 +60,7 @@ class CommandPSD4(Command):
         if self.checkValueInInterval(value, 3000, 24000):
             cmd += str(value)
         else:
-            print("Wrong parameter value for relative dispense command!")
+            print("Invalid value " + str(value) + " for PSD4 relative dispense command!")
             cmd = 'cmdError'
         return cmd
 
@@ -70,27 +70,27 @@ class CommandPSD4(Command):
         if self.checkValueInInterval(value, 3000, 24000):
             cmd += str(value)
         else:
-            print("Wrong parameter value for relative dispense with ready status command!")
+            print("Invalid value " + str(value) + " for PSD4 relative dispense with ready status command!")
             cmd = 'cmdError'
         return cmd
 
     def returnSteps(self, value: int):
-        # Return Steps x where 0 ≤ x ≤ 100 in standard mode or 0 ≤ x ≤ 800 in high resolution mode
+        # Return Steps x where 0 ≤ x ≤ 3,000 in standard mode or 0 ≤ x ≤ 24,000 in high resolution mode
         cmd: str = 'K'
-        if self.checkValueInInterval(value, 100, 800):
+        if self.checkValueInInterval(value, 3000, 24000):
             cmd += str(value)
         else:
-            print("Wrong parameter value for return steps command!")
+            print("Invalid value " + str(value) + " for PSD4 return steps command!")
             cmd = 'cmdError'
         return cmd
 
     def backoffSteps(self, value: int):
-        # Back-off Steps x where 0 ≤ x ≤ 200 in standard mode and 0≤ x ≤ 1,600
+        # Back-off Steps x where 0 ≤ x ≤ 3,000 in standard mode or 0 ≤ x ≤ 24,000
         cmd: str = 'k'
-        if self.checkValueInInterval(value, 200, 1600):
+        if self.checkValueInInterval(value, 3000, 24000):
             cmd += str(value)
         else:
-            print("Wrong parameter value for backoff steps command!")
+            print("Invalid value " + str(value) + " for PSD4 backoff steps command!")
             cmd = 'cmdError'
         return cmd
 
@@ -115,8 +115,8 @@ class CommandPSD4(Command):
         if 50 <= value <= 1000:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for PSD4 start velocity command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for set start velocity command!")
         return cmd
 
     def setMaximumVelocity(self, value: int):
@@ -124,8 +124,8 @@ class CommandPSD4(Command):
         if 2 <= value <= 5800:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for PSD4 set maximum velocity command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for set maximum velocity command!")
         return cmd
 
     def stopVelocity(self, value: int):
@@ -133,8 +133,8 @@ class CommandPSD4(Command):
         if 50 <= value <= 2700:
             cmd += str(value)
         else:
+            print("Invalid value " + str(value) + " for PSD4 stop velocity command!")
             cmd = 'cmdError'
-            print("Wrong parameter value for stop velocity command!")
         return cmd
 
     def checkValueInInterval(self, value: int, valueST: int, valueHG: int):
